@@ -9,7 +9,12 @@
 
 import numpy as np
 
-from kernels.smm_acc import kernel_algorithm
+from kernels.smm_acc import (  # noqa: F401
+    kernel_algorithm,
+    gpu_architectures,
+    params_dict_to_kernel,
+    compatible_mnk,
+)
 
 # ===============================================================================
 # Lists of derived parameters to use as training data for the predictive modelling
@@ -242,7 +247,7 @@ def get_baseline_performances_per_mnk(data, algorithm, gpu, autotuning):
                 & (data.v == baseline_pars["v"])
             ].index.tolist()
         else:
-            assert False, "Cannot recognize algorithm: " + algorithm
+            assert False, f"Cannot recognize algorithm: {algorithm}"
 
         if len(idx_baseline) == 1:
             idx_baseline = idx_baseline[0]
@@ -327,9 +332,9 @@ class PredictiveParameters:
 
         if feature_name not in self.params.columns.values:
             if feature_name != "perf_scaled":  # not vectorizable
-                vget = getattr(self, "get_" + feature_name)
+                vget = getattr(self, f"get_{feature_name}")
             else:
-                vget = np.vectorize(getattr(self, "get_" + feature_name))
+                vget = np.vectorize(getattr(self, f"get_{feature_name}"))
             feature_val = vget()
         else:
             feature_val = self.params[feature_name].values
@@ -379,7 +384,7 @@ class PredictiveParameters:
     def get_mnk_string(self):
         """Return (m, n, k) as a descriptive string"""
         return [
-            "{}x{}x{}".format(m, n, k)
+            f"{m}x{n}x{k}"
             for m, n, k in zip(self.get("m"), self.get("n"), self.get("k"))
         ]  # str
 
